@@ -1,7 +1,7 @@
 OC.L10N.register(
     "files",
     {
-    "File could not be found" : "الملف غير موجود",
+    "File could not be found" : "لم يتم العثور على الملف",
     "Move or copy" : "أنقل أو انسخ",
     "Download" : "تنزيل",
     "Delete" : "حذف ",
@@ -11,7 +11,7 @@ OC.L10N.register(
     "Home" : "الرئيسية",
     "Close" : "إغلاق",
     "Could not create folder \"{dir}\"" : "لا يمكن إنشاء المجلد \"{dir}\"",
-    "This will stop your current uploads." : "سيتم ايقاف رفع الملفات الحالية.",
+    "This will stop your current uploads." : "هذا سيقوم بوقف رفع الملفات الحالية.",
     "Upload cancelled." : "تم إلغاء عملية رفع الملفات.",
     "Processing files …" : "معالجة الملفات…",
     "…" : "...",
@@ -37,8 +37,8 @@ OC.L10N.register(
     "Set reminder" : "ضبط التذكير",
     "Edit locally" : "تعديل محليًا",
     "Open" : "افتح",
-    "Delete file" : "احذف الملف",
-    "Delete folder" : "حذف المجلد",
+    "Delete file" : "إحذِف الملف",
+    "Delete folder" : "حذف مجلد واحد",
     "Disconnect storage" : "قطع اتصال التخزين",
     "Leave this share" : "مغادرة هذه المشاركة",
     "Could not load info for file \"{file}\"" : "لم يستطع تحميل معلومات الملف \"{file}\"",
@@ -75,14 +75,14 @@ OC.L10N.register(
     "Name" : "الإسم",
     "Size" : "الحجم",
     "Modified" : "معدل",
-    "_%n folder_::_%n folders_" : ["لا توجد مجلدات","%n مجلد","مجلدان","%n مجلدات","%n مجلد","%n مجلد"],
+    "_%n folder_::_%n folders_" : ["لا توجد مجلدات","%n مجلد","مجلدان","%n مجلدات","%n مجلد","%n مجلدات"],
     "_%n file_::_%n files_" : ["لا يوجد ملفات %n","%n ملف","ملفان","%n ملفات","%n ملفات","%n ملفات"],
     "{dirs} and {files}" : "{dirs} و {files}",
     "_including %n hidden_::_including %n hidden_" : ["يشمل %n مخفي","يشمل %n مخفي","يشمل %n مخفي","يشمل %n مخفي","يشمل %n مخفي","يشمل %n مخفي"],
     "You do not have permission to upload or create files here" : "لا يوجد تخويل برفع أو إنشاء ملفات هنا",
-    "_Uploading %n file_::_Uploading %n files_" : ["لا يوجد ملفات %n لتحميلها","تحميل 1 ملف %n","تحميل 2 ملف %n","يتم تحميل عدد قليل من ملفات %n","يتم تحميل عدد كبير من ملفات %n","يتم تحميل ملفات %n"],
+    "_Uploading %n file_::_Uploading %n files_" : ["لا يوجد ملفات %n لتحميلها","تحميل 1 ملف %n","تحميل 2 ملف %n","يتم تحميل عدد قليل من ملفات %n","يتم تحميل عدد كبير من ملفات %n","جاري رفع الملفات %n"],
     "New" : "جديد",
-    "New file/folder menu" : "قائمة ملف/مجلد جديد",
+    "New file/folder menu" : "قائمة مجلد/ملف جديد",
     "Select file range" : "حدد نطاق الملف",
     "{used}%" : "{مُستخدَم}%",
     "{used} of {quota} used" : "{used} من {quota} مستخدم",
@@ -99,14 +99,14 @@ OC.L10N.register(
     "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "مجلد مجموعة \"{mountPoint}\" شبه ممتلئ ({usedSpacePercent}%).",
     "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "التخزين الخارجي \"{mountPoint}\" شبه ممتلئ ({usedSpacePercent}%).",
     "Your storage is almost full ({usedSpacePercent}%)." : "مساحة التخزين الخاصة بك شبه ممتلئة ({usedSpacePercent}%).",
-    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["تطابق \"{filter}\"","تطابق  \"{filter}\" ","تطابقان \"{filter}\"","تطابقات \"{filter}\"","تطابقات \"{filter}\"","تطابقات \"{filter}\""],
+    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["تطابق \"{filter}\"","تطابق  \"{filter}\" ","تطابقان \"{filter}\"","تطابقات \"{filter}\"","تطابقات \"{filter}\"","تطابق \"{filter}\""],
     "View in folder" : "اعرض في المجلد",
-    "Direct link was copied (only works for users who have access to this file/folder)" : "تم نسخ الرابط المباشر (تعمل فقط بالنسبة للمستخدمين الذين يملكون تخويلاً بالوصول إلى هذا الملف أو المجلد)",
+    "Direct link was copied (only works for people who have access to this file/folder)" : "تم نسخ الرابط المباشر (يعمل فقط للأشخاص الذين لديهم حق الوصول إلى هذا الملف/المجلد)",
     "Path" : "المسار",
     "_%n byte_::_%n bytes_" : ["بايت","بايت","بايت","بايت","بايت","%n بايت"],
     "Favorited" : "المفضلة",
     "Favorite" : "المفضلة",
-    "Copy direct link (only works for users who have access to this file/folder)" : "نسخ الرابط المباشر (يعمل فقط للمستخدمين الذين يمكنهم الوصول الى هذا الملف/المجلد)",
+    "Copy direct link (only works for people who have access to this file/folder)" : "نسخ الرابط المباشر (يعمل فقط للأشخاص الذين لديهم حق الوصول إلى هذا الملف/المجلد)",
     "New folder" : "مجلد جديد",
     "Create new folder" : "إنشاء مجلدا جديد",
     "Upload file" : "رفع ملف",
@@ -127,9 +127,9 @@ OC.L10N.register(
     "Restored by {user}" : "استعادة من قبل {user}",
     "Renamed by {user}" : "اعادة تسمية من قبل {user}",
     "Moved by {user}" : "نقل من قبل {user}",
-    "\"remote user\"" : "\"مستخدم عن بعد\"",
+    "\"remote account\"" : "\"حساب قصِي remote account\"",
     "You created {file}" : "أنشأتَ {file}",
-    "You created an encrypted file in {file}" : "أنت انشأت ملف مشفر في {file}",
+    "You created an encrypted file in {file}" : "انشأت ملف مشفر في {file}",
     "{user} created {file}" : "{user} انشاء ملف {file}",
     "{user} created an encrypted file in {file}" : "{user} انشاء ملف مشفر {file}",
     "{file} was created in a public folder" : "{file} انشاء ملف في المجلد العام",
@@ -161,10 +161,10 @@ OC.L10N.register(
     "Reject" : "رفض",
     "Incoming ownership transfer from {user}" : "تم تحويل ملكية الملف إليك من قبل {user}",
     "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "هل تريد الموافقة {path}?\n\nملاحظة: عملية موافقة على النقل قد تستغرق إلى 1 ساعة.",
-    "Ownership transfer failed" : "فشل نقل ملكية",
+    "Ownership transfer failed" : "فشل نقل الملكية",
     "Your ownership transfer of {path} to {user} failed." : "فشلت عمليتك لنقل الـ {path} إلى {user}",
     "The ownership transfer of {path} from {user} failed." : "فشل عملية النقل لـ {path} من قبل {user}",
-    "Ownership transfer done" : "تم نقل ملكية بنجاح",
+    "Ownership transfer done" : "تم نقل الملكية بنجاح",
     "Your ownership transfer of {path} to {user} has completed." : "عمليتك لنقل الـ {path} إلى {user} تمت بنجاح.",
     "The ownership transfer of {path} from {user} has completed." : "نقل الملكية لـ {path} من قبل {user} تمت بنجاح.",
     "in %s" : "في %s",
@@ -175,7 +175,6 @@ OC.L10N.register(
     "Drag and drop files here to upload" : "إسحَب و أفلِت الملفات هنا لرفعها",
     "Your have used your space quota and cannot upload files anymore" : "لقد استنفذت حصتك التخزينية و لم يعد بإمكانك رفع أي ملفات بعدُ",
     "You don’t have permission to upload or create files here" : "لا تملك الصلاحية لرفع او انشاء ملف هنا ",
-    "Upload successful" : "تمّ الرفع بنجاحٍ",
     "\"{displayName}\" action executed successfully" : "\"{displayName}\" الأمر نُفّذ بنجاح",
     "\"{displayName}\" action failed" : "\"{dispalyName}\" الأمر أخفق عند التنفيذ",
     "Toggle selection for file \"{displayName}\"" : "تبديل الاختيار للملف \"{displayName}\"",
@@ -185,6 +184,7 @@ OC.L10N.register(
     "Folder name" : "اسم المجلد",
     "This node is unavailable" : "هذه العُقْدَة node غير متوفرة ",
     "Download file {name}" : " تنزيل الملف {name}",
+    "Invalid file name" : "اسم الملف غير صحيح",
     "\"{name}\" is not an allowed filetype." : "\"{name}\" ليس نوع ملف مسموحًا به.",
     "{newName} already exists." : "{newName} موجود بالفعل.",
     "\"{char}\" is not allowed inside a file name." : "\"{char}\" حرفٌ غير مسموح به في اسم الملف.",
@@ -194,12 +194,11 @@ OC.L10N.register(
     "Could not rename \"{oldName}\", it does not exist any more" : "تعذر إعادة تسمية \"{oldName}\"، لم يعد موجودًا",
     "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "الاسم \"{newName}\" مُستعمَلٌ سلفاً في المجلّد\"{dir}\". إختَر اسماً آخر رجاءً.",
     "Could not rename \"{oldName}\"" : "تعذرت إعادة تسمية \"{oldName}\"",
-    "Could not copy {file}. {message}" : "تعذّر نسخ {file}. {message}",
-    "Could not move {file}. {message}" : "تعذّر نقل {file}. {message}",
     "Total rows summary" : "ملخص مجموع الأسطر",
     "Toggle selection for all files and folders" : "تبديل الاختيار لكل الملفات و المجلدات",
     "\"{displayName}\" failed on some elements " : "\"{displayName}\" فشل في بعض العناصر",
     "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" حزمة الأوامر نُفّذت بنجاح",
+    "{count} selected" : "{count} تمّ تحديدها",
     "List of files and folders." : "قائمة الملفات و المجلدات",
     "Column headers with buttons are sortable." : "ترويسات الأعمدة ذات الأزرار قابلة للترتيب.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "لم يتم عرض هذه القائمة بالكامل لأسباب تتعلق بالأداء. سيتم عرض الملفات تباعاً أثناء التنقل عبر القائمة.",
@@ -209,6 +208,8 @@ OC.L10N.register(
     "{relative}% used" : "{relative}% مستخدمة",
     "Could not refresh storage stats" : "تعذر تحديث حالة التخزين",
     "Your storage is full, files can not be updated or synced anymore!" : "مساحتك التخزينية ممتلئة, لا يمكن تحديث ملفاتك أو مزامنتها بعد الآن !",
+    "Create" : "إنشاء",
+    "A file or folder with that name already exists." : "ملف أو مجلد بنفس هذا الاسم موجود سلفاً",
     "Transfer ownership of a file or folder" : "تحويل ملكية ملف أو مجلد",
     "Choose file or folder to transfer" : "اختر ملف او مجلد لنقل الملكية",
     "Change" : "تغير",
@@ -223,7 +224,6 @@ OC.L10N.register(
     "Select file or folder to link to" : "اختر ملف أو مجلد للربط معه",
     "Choose file" : "إختَر ملفاً",
     "Choose {file}" : "إختَر {file}",
-    "Add" : "أضِف",
     "Loading current folder" : "تحميل المجلد الحالي",
     "No files in here" : "لا يوجد ملفات هنا ",
     "Upload some content or sync with your devices!" : "ارفع بعض المحتوي او زامن مع اجهزتك !",
@@ -241,6 +241,8 @@ OC.L10N.register(
     "Files settings" : "إعدادات الملفات",
     "File cannot be accessed" : "الملف لم يمكن الوصول إليه",
     "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "إمّا أن الملف غير موجود أو أنك لا تمتلك الصلاحية لعرضه. أُطلُب من المُرسل أن يتشاركه معك.",
+    "Your files" : "ملفاتك",
+    "Open in files" : "إفتَح في شاشة الملفات",
     "Sort favorites first" : "فرز المفضلات أولا",
     "Sort folders before files" : "فرز المجلدات قبل الملفات",
     "Show hidden files" : "عرض الملفات المخفية",
@@ -257,19 +259,28 @@ OC.L10N.register(
     "Unable to change the favourite state of the file" : "لم نستطع تغير الحالة المفضلة للملف",
     "Error while loading the file data" : "خطأ اثناء تحميل بيانات الملف",
     "Pick a template for {name}" : "اختر قالبا لـ {name}",
-    "Create" : "إنشاء",
     "Create a new file with the selected template" : "إنشاء ملف جديد بإستخدام القالب المحدد",
     "Creating file" : "إنشاء ملف",
     "Blank" : "فارغ",
     "Unable to create new file from template" : "تعذر إنشاء الملف الجديد من القالب",
     "Delete permanently" : "حذف بشكل دائم",
+    "Delete and unshare" : "إحذِف و الغٍ المشاركات ",
+    "Leave these shares" : "مغادرة هاتين المشاركتين",
+    "Disconnect storages" : "فصل وحدات تخزين",
+    "Delete files" : "حذف الملفات",
+    "Delete folders" : "حذف مجلدين",
+    "You are about to delete {count} items." : "أنت على وشك حذف {count} عنصر.",
+    "Confirm deletion" : "أكِّد على الحذف",
+    "Cancel" : "الغاء",
+    "Deletion cancelled" : "تمّ إلغاء الحذف",
     "Destination is not a folder" : "المَقصَد ليس مُجلّداً",
     "This file/folder is already in that directory" : "هذا الملف/المجلد موجود سلفاً في ذلك المجلد",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "لا يمكنك نقل ملف/مجلد إلى نفسه أو إلى مجلد فرعي منه",
     "(copy)" : "(نسخ)",
     "(copy %n)" : "(نسخ %n)",
+    "Move cancelled" : "تمّ إلغاء النقل",
     "A file or folder with that name already exists in this folder" : "ملف أو مجلد بنفس ذاك الاسم موجود سلفاً في هذا المجلد",
-    "The files is locked" : "الملفات مقفله",
+    "The files are locked" : "الملفات مقفلة",
     "The file does not exist anymore" : "الملف لم يعد موجوداً",
     "Choose destination" : "إختَر المَقصِد",
     "Copy to {target}" : "أُنسُخ إلى {target}",
@@ -279,12 +290,27 @@ OC.L10N.register(
     "Open folder {displayName}" : "إفتح المجلد {displayName}",
     "Open in Files" : "إفتَح في \"الملفات\"",
     "Open details" : "افتح التفاصيل",
+    "Created new folder \"{name}\"" : "تمّ إنشاء مجلد جديد باسم \"{name}\"",
+    "Filename" : "اسم الملف",
+    "Unable to initialize the templates directory" : "تعذر تهيئة دليل القوالب",
     "Create new templates folder" : "إنشيْ مجلد جديد للقوالب",
     "Templates" : "القوالب",
-    "Unable to initialize the templates directory" : "تعذر تهيئة دليل القوالب",
-    "Created new folder \"{name}\"" : "تمّ إنشاء مجلد جديد باسم \"{name}\"",
+    "New template folder" : "مجلد القوالب الجديد",
+    "In folder" : "في المجلد",
+    "Search in folder: {folder}" : "البحث في المجلد:  {folder}",
     "One of the dropped files could not be processed" : "أحد الملفات المُفلَتة لا يمكن معالجته",
-    "Uploading \"{filename}\" failed" : "فشل في تحديث \"{filename}\" ",
+    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "مُستعرِضُك لا يدعم واجهة تطبيق نظام الملفات Filesystem API. لذا، لن يُمكن رفع المجلدات",
+    "No files to upload" : "لا توجد ملفات لرفعها",
+    "Unable to create the directory {directory}" : "تعذّر إنشاء الدليل {directory}",
+    "Some files could not be uploaded" : "بعض الملفات لم يمكن رفعها",
+    "Files uploaded successfully" : "تمّ رفع الملفات بنجاحٍ",
+    "No files to process" : "لا توجد ملفات لمعالجتها",
+    "Some files could not be copied" : "بعض الملفات لا يمكن نسخها",
+    "Some files could not be moved" : "تعذر نقل بعض الملفات",
+    "Files copied successfully" : "تمّ نسخ الملفات بنجاحٍ",
+    "Files moved successfully" : "تمّ نقل الملفات بنجاحٍ",
+    "Conflicts resolution skipped" : "تمّ تخطّي حلّ التعارضات",
+    "Upload cancelled" : "تمّ إلغاء الرفع",
     "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} مجلد","{folderCount} مجلد","{folderCount} مجلدان","{folderCount} مجلد","{folderCount} مجلدات","{folderCount} مجلدات"],
     "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} ملف","{fileCount} ملف","{fileCount} ملفان","{fileCount} ملف","{fileCount} ملفات","{fileCount} ملفات"],
     "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["ملف واحد 1 و {folderCount} مجلد","ملف واحد 1 و {folderCount} مجلد","ملف واحد 1 و {folderCount} مجلدان","ملف واحد 1 و {folderCount} مجلد","ملف واحد 1 و {folderCount} مجلدات","ملف واحد 1 و {folderCount} مجلدات"],
@@ -295,6 +321,10 @@ OC.L10N.register(
     "Files and folders you mark as favorite will show up here" : "الملفات والمجلدات التي حددتها كامفضلة سوف تظهر هنا ",
     "All files" : "كل الملفات",
     "List of your files and folders." : "قائمة بملفاتك و مجلداتك",
+    "Personal Files" : "ملفات شخصية",
+    "List of your files and folders that are not shared." : "قائمة بالملفات و المجلدات التي لم تتم مشاركتها.",
+    "No personal files found" : "لا توجد أي ملفات شخصية",
+    "Files that are not shared will show up here." : "الملفات التي لم تتم مشاركتها ستُعرض هنا",
     "List of recently modified files and folders." : "قائمة بالملفات و المجلدات التي تمّ تعديلها مؤخراً.",
     "No recently modified files" : "لا توجد أيّ ملفات تمّ تعديلها مؤخراً",
     "Files and folders you recently modified will show up here." : "الملفات و المجلدات التي تمّ تعديلها مؤخراً ستظهر هنا.",
@@ -304,21 +334,12 @@ OC.L10N.register(
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "حجم الملفات التي تريد ترفيعها أعلى من المسموح على الخادم.",
     "Text file" : "ملف نصي",
     "New text file.txt" : "ملف نصي جديد fille.txt",
+    "Direct link was copied (only works for users who have access to this file/folder)" : "تم نسخ الرابط المباشر (تعمل فقط بالنسبة للمستخدمين الذين يملكون تخويلاً بالوصول إلى هذا الملف أو المجلد)",
+    "Copy direct link (only works for users who have access to this file/folder)" : "نسخ الرابط المباشر (يعمل فقط للمستخدمين الذين يمكنهم الوصول الى هذا الملف/المجلد)",
     "You can only favorite a single file or folder at a time" : "يمكنك فقط تفضيل ملف أو مجلد واحد في المرة الواحدة",
-    "Search users" : "ابحث عن مستخدمين",
-    "You might not have have permissions to view it, ask the sender to share it" : "يمكن ألاّ تكون لديك صلاحية لعرضه، أطلب من المُرسل إن يشاركه معك",
-    "Cancel" : "الغاء",
-    "Set up templates folder" : "إعداد مجلد القوالب",
-    "Toggle %1$s sublist" : "تبديل %1$s قائمة فرعية",
-    "Toggle grid view" : "تفعيل/تعطيل القائمة",
-    "Deleted files" : "الملفات المحذوفة",
-    "Shares" : "التي قمتَ بمشاركتها",
-    "Shared with others" : "شاركته مع الاخرين",
-    "Shared with you" : "تمت مشاركته معك",
-    "Deleted shares" : "تم حذف المشاركات",
-    "Pending shares" : "انتظار المشاركات",
     "This file has the tag {tag}" : "هذا الملف له واصفة {tag}",
     "This file has the tags {firstTags} and {lastTag}" : "هذا الملف له واصفات {firstTags} و {lastTag}",
+    "\"remote user\"" : "\"مستخدم عن بعد\"",
     "Select the row for {displayName}" : "إختر السطر في {displayName}",
     "Open folder {name}" : "إفتح المجلد {name}",
     "Unselect all" : "إلغاء الاختيار للكل",
@@ -328,6 +349,16 @@ OC.L10N.register(
     "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "لم يمكن عرض هذه القائمة بالكامل بسبب إشكالية في الأداء. سيتم عرض الملفات عندما تمر عليها في القائمة",
     "Search for an account" : "البحث عن حساب",
     "Choose" : "إختَر",
-    "No files or folders have been deleted yet" : "لم يتم حذف أي ملفات أو مجلدات بعدُ"
+    "No files or folders have been deleted yet" : "لم يتم حذف أي ملفات أو مجلدات بعدُ",
+    "You might not have have permissions to view it, ask the sender to share it" : "يمكن ألاّ تكون لديك صلاحية لعرضه، أطلب من المُرسل إن يشاركه معك",
+    "Set up templates folder" : "إعداد مجلد القوالب",
+    "Toggle %1$s sublist" : "تبديل %1$s قائمة فرعية",
+    "Toggle grid view" : "تفعيل/تعطيل القائمة",
+    "Shares" : "التي قمتَ بمشاركتها",
+    "Shared with others" : "شاركته مع الاخرين",
+    "Shared with you" : "تمت مشاركته معك",
+    "Deleted shares" : "تم حذف المشاركات",
+    "Pending shares" : "انتظار المشاركات",
+    "The files is locked" : "الملفات مقفله"
 },
 "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
