@@ -3,9 +3,9 @@ OC.L10N.register(
     {
     "File could not be found" : "Filen kunne ikke findes",
     "Move or copy" : "Flyt eller kopier",
-    "Download" : "Hent",
+    "Download" : "Download",
     "Delete" : "Slet",
-    "Tags" : "Mærker",
+    "Tags" : "Tags",
     "Show list view" : "Vis som liste",
     "Show grid view" : "Vis som gitter",
     "Home" : "Hjem",
@@ -22,6 +22,8 @@ OC.L10N.register(
     "An unknown error has occurred" : "En ukendt fejl er opstået",
     "File could not be uploaded" : "Filen kunne ikke uploades",
     "Uploading …" : "Uploader ...",
+    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
+    "Uploading … ({currentNumber}/{total})" : "Uploader … ({currentNumber}/{total})",
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} af {totalSize} ({bitrate})",
     "Uploading that item is not supported" : "Upload af dette er ikke supporteret",
     "Target folder does not exist any more" : "Destinationsmappen findes ikke længere",
@@ -32,6 +34,7 @@ OC.L10N.register(
     "Move" : "Flyt",
     "Copy" : "Kopier",
     "Choose target folder" : "Vælg destinationsmappe",
+    "Set reminder" : "Sæt påmindelse",
     "Edit locally" : "Rediger lokalt",
     "Open" : "Åbn",
     "Delete file" : "Slet fil",
@@ -78,6 +81,7 @@ OC.L10N.register(
     "_including %n hidden_::_including %n hidden_" : ["%n skujlte inkluderet","%n skujlte inkluderet"],
     "You do not have permission to upload or create files here" : "Du har ikke tilladelse til at uploade eller oprette filer her",
     "_Uploading %n file_::_Uploading %n files_" : ["Uploader %n fil","Uploader %n filer"],
+    "New" : "Ny",
     "New file/folder menu" : "Ny fil/mappe menu",
     "Select file range" : "Vælg filområde",
     "{used}%" : "{used}%",
@@ -97,18 +101,14 @@ OC.L10N.register(
     "Your storage is almost full ({usedSpacePercent}%)." : "Din lagerplads er næsten fuld ({usedSpacePercent}%).",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["matches \"{filter}\"","match \"{filter}\""],
     "View in folder" : "Vis i mappe",
-    "Direct link was copied (only works for users who have access to this file/folder)" : "Linket er kopieret (dette link kan kun anvendes af brugere med adgang til denne fil/mappe)",
     "Path" : "Sti",
     "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
     "Favorited" : "Gjort til foretrukken",
     "Favorite" : "Foretrukken",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Kopier direkte link (virker kun for brugere der har adgang til denne fil/mappe)",
     "New folder" : "Ny mappe",
     "Create new folder" : "Opret ny mappe",
     "Upload file" : "Upload fil",
     "Recent" : "Seneste",
-    "This file has the tag {tag}" : "Denne fil har tagget {tag}",
-    "This file has the tags {firstTags} and {lastTag}" : "Denne fil har taggene {firstTags} og {lastTag}",
     "Not favorited" : "Ingen foretrukne",
     "Remove from favorites" : "Fjern fra favoritter",
     "Add to favorites" : "Tilføj til favoritter",
@@ -125,7 +125,6 @@ OC.L10N.register(
     "Restored by {user}" : "Gendannet af {user}",
     "Renamed by {user}" : "Omdøbt af {user}",
     "Moved by {user}" : "Flyttet af {user}",
-    "\"remote user\"" : "\"ekstern bruger\"",
     "You created {file}" : "Du har oprettet {file}",
     "You created an encrypted file in {file}" : "Du har oprettet en krypteret fil i {file}",
     "{user} created {file}" : "{user} oprettede {file}",
@@ -154,7 +153,6 @@ OC.L10N.register(
     "A file has been added to or removed from your <strong>favorites</strong>" : "En fil er blevet tilføjet eller fjernet fra dine <strong>favoritter</strong>",
     "A file or folder has been <strong>changed</strong>" : "En fil eller mappe er blevet <strong>ændret</strong>",
     "A favorite file or folder has been <strong>changed</strong>" : "En favoritfil eller -mappe er blevet <strong>ændret</strong>",
-    "All files" : "Alle filer",
     "Upload (max. %s)" : "Upload (max. %s)",
     "Accept" : "Accepter",
     "Reject" : "Afvis",
@@ -170,12 +168,36 @@ OC.L10N.register(
     "File Management" : "Filhåndtering",
     "Reload current directory" : "Genindlæs den aktuelle mappe",
     "Go to the \"{dir}\" directory" : "Gå til mappen \"{dir}\"",
+    "Drag and drop files here to upload" : "Træk filer hertil for at uploade",
+    "You don’t have permission to upload or create files here" : "Du har ikke tilladelse til at uploade eller oprette filer her",
+    "\"{displayName}\" action executed successfully" : "\"{displayName}\"-handling blev udført korrekt",
+    "\"{displayName}\" action failed" : "\"{displayName}\"-handling mislykkedes",
+    "Rename file" : "Omdøb fil",
+    "File name" : "Filnavn",
+    "Folder name" : "Mappenavn",
+    "This node is unavailable" : "Denne node er ikke tilgængelig ",
+    "Download file {name}" : "Download fil {name}",
+    "\"{name}\" is not an allowed filetype." : "\"{name}\" er ikke en tilladt filtype.",
+    "{newName} already exists." : "{newName} findes allerede.",
+    "\"{char}\" is not allowed inside a file name." : "\"{char}\" er ikke tilladt i filnavnet",
     "Name cannot be empty" : "Navn må ikke være tomt",
-    "Select all" : "Vælg alle",
+    "Another entry with the same name already exists" : "Dette navn er allerede i brug",
+    "Renamed \"{oldName}\" to \"{newName}\"" : "Omdøbte \"{oldName}\" til \"{newName}\"",
+    "Could not rename \"{oldName}\", it does not exist any more" : "Kunne ikke omdøbe \"{oldName}\", da den findes ikke længere",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Navnet \"{newName}\" bruges allerede i mappen \"{dir}\". Vælg et andet navn.",
+    "Could not rename \"{oldName}\"" : "Kunne ikke omdøbe \"{oldName}\"",
+    "Total rows summary" : "Samlet række antal",
+    "\"{displayName}\" failed on some elements " : "\"{displayName}\" fejlede i nogle aspekter.",
+    "\"{displayName}\" batch action executed successfully" : "\"{displayName}\"-handling blev udført korrekt",
+    "List of files and folders." : "Liste med filer og mapper.",
+    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Hele listen er ikke hentet, af hensyn til størrelsen. Listen vil blive hentet løbende som du kører igennem listen.",
+    "File not found" : "Filen blev ikke fundet",
     "Storage informations" : "Lagerinformationer",
     "{usedQuotaByte} used" : "{usedQuotaByte} brugt",
     "{relative}% used" : "{relative}% brugt",
     "Could not refresh storage stats" : "Kunne ikke opdatere lageroplysninger",
+    "Your storage is full, files can not be updated or synced anymore!" : "Din opbevaringsplads er fyldt op, filer kan ikke opdateres eller synkroniseres længere!",
+    "Create" : "Opret",
     "Transfer ownership of a file or folder" : "Overfør ejerskab af en fil eller mappe",
     "Choose file or folder to transfer" : "Vælg fil eller mappe til overførsel",
     "Change" : "Ændr",
@@ -188,57 +210,102 @@ OC.L10N.register(
     "Ownership transfer request sent" : "Anmodning om ejerskabsoverdragelse sendt",
     "Cannot transfer ownership of a file or folder you do not own" : "Kan ikke overføre ejerskab af en fil eller mappe, du ikke ejer",
     "Select file or folder to link to" : "Vælg fil eller mappe at linke til",
+    "Choose {file}" : "Vælg {file}",
+    "Loading current folder" : "Indlæser aktuelle mappe",
     "No files in here" : "Her er ingen filer",
     "Upload some content or sync with your devices!" : "Overfør indhold eller synkronisér med dine enheder!",
+    "Go to the previous folder" : "Gå til forrige mappe",
     "Go back" : "Gå tilbage",
+    "Share" : "Del",
+    "Shared by link" : "Delt via link",
+    "Shared" : "Delt",
+    "Switch to list view" : "Skift til listevisning",
+    "Switch to grid view" : "Skift til gittervisning",
     "Open the files app settings" : "Åbn fil-app indstillinger",
     "Files settings" : "indstillinger for filer",
     "File cannot be accessed" : "Filen kan ikke tilgås",
-    "You might not have have permissions to view it, ask the sender to share it" : "Du har muligvis ikke tilladelser til at se.... Bed afsenderen om at dele...",
+    "Open in files" : "Åben i Filer",
+    "Sort favorites first" : "Vis favoritter først",
     "Show hidden files" : "Vis skjulte filer",
     "Crop image previews" : "Beskær forhåndsvisninger af billeder",
+    "Enable the grid view" : "Aktivér gittervisning",
     "Additional settings" : "Yderligere indstillinger",
     "WebDAV" : "WebDAV",
     "Copy to clipboard" : "Kopier til udklipsholder",
     "Use this address to access your Files via WebDAV" : "Brug denne adresse til at få adgang til dine filer via WebDAV",
+    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Hvis du har aktiveret 2-faktor godkendelse, skal du oprette en app-token, ved at følge dette link.",
     "Clipboard is not available" : "Udklipsholderen er ikke tilgængelig",
     "WebDAV URL copied to clipboard" : "WebDAV URL kopieret til udklipsholder",
     "Unable to change the favourite state of the file" : "Kan ikke ændre favorittilstanden for filen",
     "Error while loading the file data" : "Fejl under indlæsning af fildata",
     "Pick a template for {name}" : "Vælg en skabelon til {name}",
-    "Create" : "Opret",
     "Create a new file with the selected template" : "Opret en ny fil med den valgte skabelon",
     "Creating file" : "Opretter fil",
     "Blank" : "Tom",
     "Unable to create new file from template" : "Kan ikke oprette ny fil fra skabelonen",
     "Delete permanently" : "Slet permanent",
+    "Cancel" : "annuller",
+    "Destination is not a folder" : "Destinationen er ikke en mappe",
+    "This file/folder is already in that directory" : "Filen/mappen er allerede i denne mappe",
+    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Du kan ikke flytte en fil/mappe ind i sig selv, eller til en mappe inden i sig selv",
+    "A file or folder with that name already exists in this folder" : "En fil eller mappe med det navn findes allerede i denne mappe",
+    "The file does not exist anymore" : "Filen findes ikke længere",
+    "Copy to {target}" : "Kopiér til {target}",
+    "Move to {target}" : "Flyt til {target}",
+    "Cancelled move or copy operation" : "Flytning eller kopiering er annulleret",
+    "Open folder {displayName}" : "Åben mappe {displayName}",
+    "Open in Files" : "Åben i Filer",
     "Open details" : "Mere information",
-    "Set up templates folder" : "Opsæt skabelonmappen",
-    "Templates" : "Skabeloner",
+    "Created new folder \"{name}\"" : "Oprettede ny mappe \"{name}\"",
+    "Filename" : "Filnavn",
     "Unable to initialize the templates directory" : "Kan ikke initialisere skabelonmappen",
+    "Create new templates folder" : "Opsæt ny skabelonmappe",
+    "Templates" : "Skabeloner",
+    "Some files could not be moved" : "Nogle filer kunne ikke flyttes",
+    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} mappe","{folderCount} mapper"],
+    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} fil","{fileCount} filer"],
+    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 fil og {folderCount} mapper","1 fil og {folderCount} mapper"],
+    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} fil og 1 mapper","{fileCount} filer og 1 mapper"],
+    "{fileCount} files and {folderCount} folders" : "{fileCount} filer og {folderCount} mapper",
+    "List of favorites files and folders." : "Liste med foretrukne filer og mapper.",
     "No favorites yet" : "Ingen foretrukne endnu",
     "Files and folders you mark as favorite will show up here" : "Filer og mapper som du har markeret som foretrukne, vil blive vist her",
-    "Toggle %1$s sublist" : "Skift %1$s underliste",
-    "Toggle grid view" : "Vis som gitter",
+    "All files" : "Alle filer",
+    "List of your files and folders." : "Liste med dine filer og mapper.",
+    "List of recently modified files and folders." : "Liste med nyligt ændrede filer og mapper.",
+    "No recently modified files" : "Ingen filer er ændret for nyligt",
+    "Files and folders you recently modified will show up here." : "Filer og mapper som du har ændret for nyligt, vil blive vist her.",
     "No entries found in this folder" : "Der blev ikke fundet poster i denne mappe",
+    "Select all" : "Vælg alle",
     "Upload too large" : "Upload er for stor",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Filerne, du prøver at uploade, er større end den maksimale størrelse for fil-upload på denne server.",
     "Text file" : "Tekstfil",
     "New text file.txt" : "Ny tekst fil.txt",
-    "Storage invalid" : "Lagerplads er ugyldig",
+    "Direct link was copied (only works for users who have access to this file/folder)" : "Linket er kopieret (dette link kan kun anvendes af brugere med adgang til denne fil/mappe)",
+    "Copy direct link (only works for users who have access to this file/folder)" : "Kopier direkte link (virker kun for brugere der har adgang til denne fil/mappe)",
     "You can only favorite a single file or folder at a time" : "Du kan kun favorisere en enkelt fil eller mappe ad gangen",
-    "Unlimited" : "Ubegrænset",
-    "Search users" : "Søg efter brugere",
-    "Cancel" : "annuller",
-    "%s used" : "%s brugt",
-    "%s%%" : "%s%%",
-    "%1$s of %2$s used" : "%1$s af %2$s brugt",
-    "Deleted files" : "Slettede filer",
+    "This file has the tag {tag}" : "Denne fil har tagget {tag}",
+    "This file has the tags {firstTags} and {lastTag}" : "Denne fil har taggene {firstTags} og {lastTag}",
+    "\"remote user\"" : "\"ekstern bruger\"",
+    "Select the row for {displayName}" : "Vælg rækken for {displayName}",
+    "Open folder {name}" : "Åben mappe {name}",
+    "Unselect all" : "Fravælg alle",
+    "ascending" : "stigende",
+    "descending" : "faldende",
+    "Sort list by {column} ({direction})" : "Sortér liste efter {column} ({direction})",
+    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Hele listen er ikke hentet, af hensyn til størrelsen. Listen vil blive hentet løbende som du kører igennem listen.",
+    "Search for an account" : "Søg efter en konto",
+    "Choose" : "Vælg",
+    "No files or folders have been deleted yet" : "Ingen filer eller mappe er slettet endnu",
+    "You might not have have permissions to view it, ask the sender to share it" : "Du har muligvis ikke tilladelser til at se.... Bed afsenderen om at dele...",
+    "Set up templates folder" : "Opsæt skabelonmappen",
+    "Toggle %1$s sublist" : "Skift %1$s underliste",
+    "Toggle grid view" : "Vis som gitter",
     "Shares" : "Delinger",
     "Shared with others" : "Delt med andre",
     "Shared with you" : "Delt med dig",
-    "Shared by link" : "Delt via link",
     "Deleted shares" : "Slettede delinger",
-    "Pending shares" : "Afventende delinger"
+    "Pending shares" : "Afventende delinger",
+    "The files is locked" : "Filerne er låste"
 },
 "nplurals=2; plural=(n != 1);");
