@@ -12,11 +12,11 @@ OC.L10N.register(
     "Close" : "Fermer",
     "Could not create folder \"{dir}\"" : "Impossible de créer le dossier \"{dir}\"",
     "This will stop your current uploads." : "Cela va arrêter vos envois en cours.",
-    "Upload cancelled." : "Envoi annulé.",
+    "Upload cancelled." : "Téléversement annulé.",
     "Processing files …" : "Fichiers en cours de traitement …",
     "…" : "…",
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "Impossible de téléverser {filename} car il s'agit d'un dossier ou d'un fichier vide",
-    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Espace libre insuffisant : vous tentez d'envoyer {size1} mais seulement {size2} sont disponibles",
+    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Espace libre insuffisant : vous tentez d’envoyer {size1} mais seulement {size2} sont disponibles",
     "Target folder \"{dir}\" does not exist any more" : "Le dossier cible \"{dir}\" n'existe plus",
     "Not enough free space" : "Espace disponible insuffisant",
     "An unknown error has occurred" : "Une erreur inconnue est survenue",
@@ -37,7 +37,7 @@ OC.L10N.register(
     "Set reminder" : "Définir un rappel",
     "Edit locally" : "Éditer localement",
     "Open" : "Ouvrir",
-    "Delete file" : "Supprimer le fichier",
+    "Delete file" : "Supprimer le fichier ",
     "Delete folder" : "Supprimer le dossier",
     "Disconnect storage" : "Déconnecter ce support de stockage",
     "Leave this share" : "Quitter ce partage",
@@ -63,9 +63,9 @@ OC.L10N.register(
     "Failed to redirect to client" : "Échec de la redirection vers le client",
     "{newName} already exists" : "{newName} existe déjà",
     "Could not rename \"{fileName}\", it does not exist any more" : "Impossible de renommer \"{fileName}\" car il n'existe plus",
-    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Le nom \"{targetName}\" est déjà utilisé dans le dossier \"{dir}\". Merci de choisir un nom différent.",
+    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Le nom « {targetName} » est déjà utilisé dans le dossier « {dir} ». Merci de choisir un nom différent.",
     "Could not rename \"{fileName}\"" : "Impossible de renommer « {fileName} »",
-    "Could not create file \"{file}\"" : "Impossible de créer le fichier \"{file}\"",
+    "Could not create file \"{file}\"" : "Impossible de créer le fichier « {file} »",
     "Could not create file \"{file}\" because it already exists" : "Impossible de créer le fichier « {file} » car il existe déjà",
     "Could not create folder \"{dir}\" because it already exists" : "Impossible de créer le dossier \"{dir}\" car il existe déjà",
     "Could not fetch file details \"{file}\"" : "Impossible de récupérer les détails du fichier \"{file}\"",
@@ -87,7 +87,7 @@ OC.L10N.register(
     "{used}%" : "{used}%",
     "{used} of {quota} used" : "{used} utilisés sur {quota}",
     "{used} used" : "{used} utilisés",
-    "\"{name}\" is an invalid file name." : "\"{name}\" n'est pas un nom de fichier valide.",
+    "\"{name}\" is an invalid file name." : "« {name} » n’est pas un nom de fichier valide.",
     "File name cannot be empty." : "Le nom de fichier ne peut pas être vide.",
     "\"/\" is not allowed inside a file name." : "\"/\" n'est pas autorisé dans un nom de fichier.",
     "\"{name}\" is not an allowed filetype" : "\"{name}\" n'est pas un type de fichier autorisé",
@@ -101,12 +101,12 @@ OC.L10N.register(
     "Your storage is almost full ({usedSpacePercent}%)." : "Votre espace de stockage est presque plein ({usedSpacePercent}%).",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["correspond à \"{filter}\"","correspondent à '{filter}'","correspondent à '{filter}'"],
     "View in folder" : "Afficher dans le dossier",
-    "Direct link was copied (only works for users who have access to this file/folder)" : "Le lien direct a été copié (fonctionne uniquement pour les utilisateurs qui ont accès à ce fichier/dossier)",
+    "Direct link was copied (only works for people who have access to this file/folder)" : "Le lien direct a été copié (fonctionne uniquement pour les personnes qui ont accès à ce fichier ou à ce dossier)",
     "Path" : "Chemin",
     "_%n byte_::_%n bytes_" : ["%n octet","%n octets","%n octets"],
     "Favorited" : "Marqué comme favori",
     "Favorite" : "Favoris",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Copier le Lien direct (fonctionne uniquement pour les utilisateurs autorisés à accéder à ce fichier ou à ce dossier)",
+    "Copy direct link (only works for people who have access to this file/folder)" : "Copier le lien direct (fonctionne uniquement pour les personnes pouvant accéder à ce fichier ou à ce dossier)",
     "New folder" : "Nouveau dossier",
     "Create new folder" : "Créer un nouveau dossier",
     "Upload file" : "Téléverser un fichier",
@@ -127,7 +127,7 @@ OC.L10N.register(
     "Restored by {user}" : "Restauré par {user}",
     "Renamed by {user}" : "Renommé par {user}",
     "Moved by {user}" : "Déplacé par {user}",
-    "\"remote user\"" : "\"utilisateur distant\"",
+    "\"remote account\"" : "« compte distant »",
     "You created {file}" : "Vous avez créé {file}",
     "You created an encrypted file in {file}" : "Vous avez créé un fichier chiffré dans {file}",
     "{user} created {file}" : "{user} a créé {file}",
@@ -175,7 +175,6 @@ OC.L10N.register(
     "Drag and drop files here to upload" : "Glissez-déposez les fichiers ici pour les téléverser",
     "Your have used your space quota and cannot upload files anymore" : "Vous avez utilisé votre quota d'espace et vous ne pouvez plus téléverser de fichiers",
     "You don’t have permission to upload or create files here" : "Vous n'avez pas la permission d'envoyer ou de créer des fichiers ici",
-    "Upload successful" : "Téléversement réussi",
     "\"{displayName}\" action executed successfully" : "Action \"{displayName}\" exécutée avec succès",
     "\"{displayName}\" action failed" : "Échec de l'action \"{displayName}\"",
     "Toggle selection for file \"{displayName}\"" : "Basculer la sélection pour le fichier « {displayName} »",
@@ -185,6 +184,7 @@ OC.L10N.register(
     "Folder name" : "Nom du dossier",
     "This node is unavailable" : "Ce nœud est indisponible ",
     "Download file {name}" : "Télécharger le fichier {name}",
+    "Invalid file name" : "Nom de fichier invalide",
     "\"{name}\" is not an allowed filetype." : "\"{name}\" n'est pas un type de fichier autorisé.",
     "{newName} already exists." : "{newName} existe déjà.",
     "\"{char}\" is not allowed inside a file name." : "\"{char}\" n'est pas autorisé dans un nom de fichier.",
@@ -194,12 +194,11 @@ OC.L10N.register(
     "Could not rename \"{oldName}\", it does not exist any more" : "Impossible de renommer \"{oldName}\", il n'existe plus.",
     "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Le nom \"{newName}\" est déjà utilisé dans le dossier \"{dir}\". Veuillez choisir un autre nom.",
     "Could not rename \"{oldName}\"" : "Impossible de renommer \"{oldName}\"",
-    "Could not copy {file}. {message}" : "Impossible de copier {file}. {message}",
-    "Could not move {file}. {message}" : "Impossible de déplacer {file}. {message}",
     "Total rows summary" : "Récapitulatif du nombre total de lignes",
     "Toggle selection for all files and folders" : "Basculer la sélection pour tous les fichiers et dossiers",
     "\"{displayName}\" failed on some elements " : "\"{displayName}\" a échoué sur certains éléments",
-    "\"{displayName}\" batch action executed successfully" : "L'action « {displayName} » par lot a été exécutée avec succès",
+    "\"{displayName}\" batch action executed successfully" : "L’action « {displayName} » par lot a été exécutée avec succès",
+    "{count} selected" : "{count} sélectionné(s)",
     "List of files and folders." : "Liste des fichiers et dossiers.",
     "Column headers with buttons are sortable." : "L'entête des colonnes avec des boutons sont triables.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Cette liste n'est pas entièrement affichée pour des raisons de performances. Les fichiers seront affichés au fur et à mesure que vous naviguerez dans la liste.",
@@ -209,6 +208,8 @@ OC.L10N.register(
     "{relative}% used" : "{relative}% utilisés",
     "Could not refresh storage stats" : "Impossible de rafraîchir les statistiques de stockage",
     "Your storage is full, files can not be updated or synced anymore!" : "Votre espace de stockage est plein. Les fichiers ne peuvent plus être mis à jour ni synchronisés !",
+    "Create" : "Créer",
+    "A file or folder with that name already exists." : "Un fichier ou un dossier portant ce nom existe déjà.",
     "Transfer ownership of a file or folder" : "Transférer la propriété d'un fichier ou d'un dossier",
     "Choose file or folder to transfer" : "Sélectionnez un fichier ou un dossier à transférer",
     "Change" : "Modifier",
@@ -223,7 +224,6 @@ OC.L10N.register(
     "Select file or folder to link to" : "Sélectionnez le fichier ou le dossier à lier",
     "Choose file" : "Choisir un fichier",
     "Choose {file}" : "Choisir {file}",
-    "Add" : "Ajouter",
     "Loading current folder" : "Chargement du dossier courant",
     "No files in here" : "Aucun fichier",
     "Upload some content or sync with your devices!" : "Déposez du contenu ou synchronisez vos appareils !",
@@ -240,6 +240,9 @@ OC.L10N.register(
     "Open the files app settings" : "Ouvrir les paramètres de l'application Fichiers",
     "Files settings" : "Paramètres de Fichiers",
     "File cannot be accessed" : "Impossible d'accéder au fichier",
+    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Le fichier n'a pas été trouv ou vous n'avez pas les permissions pour le voir. Demandez à l'expéditeur de le partager.",
+    "Your files" : "Vos fichiers",
+    "Open in files" : "Ouvrir dans Fichiers",
     "Sort favorites first" : "Trier les favoris d'abord",
     "Sort folders before files" : "Trier les dossiers avant les fichiers",
     "Show hidden files" : "Afficher les fichiers masqués",
@@ -256,19 +259,28 @@ OC.L10N.register(
     "Unable to change the favourite state of the file" : "Impossible de modifier l'état favori du fichier",
     "Error while loading the file data" : "Erreur lors du chargement du fichier de données",
     "Pick a template for {name}" : "Choisissez un modèle pour {name}",
-    "Create" : "Créer",
     "Create a new file with the selected template" : "Créer un nouveau fichier avec le modèle sélectionné",
     "Creating file" : "Créer un fichier",
     "Blank" : "Vide",
     "Unable to create new file from template" : "Impossible de créer un nouveau fichier à partir du modèle",
     "Delete permanently" : "Supprimer définitivement",
+    "Delete and unshare" : "Supprimer et ne plus partager",
+    "Leave these shares" : "Quitter ces partages",
+    "Disconnect storages" : "Déconnecter les supports de stockage",
+    "Delete files" : "Supprimer les fichiers",
+    "Delete folders" : "Supprimer les dossiers",
+    "You are about to delete {count} items." : "Vous êtes sur le point de supprimer {count} éléments.",
+    "Confirm deletion" : "Confirmer la suppression",
+    "Cancel" : "Annuler",
+    "Deletion cancelled" : "Suppression annulée",
     "Destination is not a folder" : "La destination n'est pas un dossier",
     "This file/folder is already in that directory" : "Ce fichier/dossier se trouve déjà dans ce dossier",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Vous ne pouvez pas déplacer un fichier/dossier sur lui-même ou dans un sous-dossier de celui-ci",
     "(copy)" : "(copier)",
     "(copy %n)" : "(copier %n)",
+    "Move cancelled" : "Déplacement annulé",
     "A file or folder with that name already exists in this folder" : "Un fichier ou un dossier portant ce nom existe déjà dans ce dossier",
-    "The files is locked" : "Le fichier est verrouillé",
+    "The files are locked" : "Les fichiers sont verrouillés",
     "The file does not exist anymore" : "Le fichier n'existe plus",
     "Choose destination" : "Choisir la destination",
     "Copy to {target}" : "Copier vers {target}",
@@ -278,12 +290,27 @@ OC.L10N.register(
     "Open folder {displayName}" : "Ouvrir le dossier {displayName}",
     "Open in Files" : "Ouvrir dans Fichiers",
     "Open details" : "Ouvrir les détails",
+    "Created new folder \"{name}\"" : "Nouveau dossier \"{name}\" créé",
+    "Filename" : "Nom du fichier",
+    "Unable to initialize the templates directory" : "Impossible d'initialiser le dossier des modèles",
     "Create new templates folder" : "Créer un nouveau dossier de modèles",
     "Templates" : "Modèles",
-    "Unable to initialize the templates directory" : "Impossible d'initialiser le dossier des modèles",
-    "Created new folder \"{name}\"" : "Nouveau dossier \"{name}\" créé",
+    "New template folder" : "Nouveau modèle de dossier",
+    "In folder" : "Dans le dossier",
+    "Search in folder: {folder}" : "Rechercher dans le dossier : {folder}",
     "One of the dropped files could not be processed" : "L'un des fichiers déposés n'a pas pu être traité",
-    "Uploading \"{filename}\" failed" : "Le téléversement de « {filename} » a échoué",
+    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Votre navigateur n’est pas compatible avec l’API Filesystem. Les dossiers ne seront pas téléversés",
+    "No files to upload" : "Aucun fichier à téléverser",
+    "Unable to create the directory {directory}" : "Impossible de créer le répertoire {directory}",
+    "Some files could not be uploaded" : "Certains fichiers n'ont pu être téléversés",
+    "Files uploaded successfully" : "Fichiers téléversés avec succès",
+    "No files to process" : "Aucun fichier à traiter",
+    "Some files could not be copied" : "Certains des fichiers n’ont pas pu être copiés",
+    "Some files could not be moved" : "Certains fichiers n’ont pu être déplacés",
+    "Files copied successfully" : "Fichiers copiés avec succès",
+    "Files moved successfully" : "Fichiers déplacés avec succès",
+    "Conflicts resolution skipped" : "Résolution des conflits ignorée",
+    "Upload cancelled" : "Téléversement annulé",
     "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} dossier","{folderCount} dossiers","{folderCount} dossiers"],
     "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} fichier","{fileCount} fichiers","{fileCount} fichiers"],
     "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 fichier et {folderCount} dossier","1 fichier et {folderCount} dossiers","1 fichier et {folderCount} dossiers"],
@@ -294,30 +321,25 @@ OC.L10N.register(
     "Files and folders you mark as favorite will show up here" : "Les fichiers et dossiers ajoutés à vos favoris apparaîtront ici",
     "All files" : "Tous les fichiers",
     "List of your files and folders." : "Liste de vos fichiers et dossiers.",
+    "Personal Files" : "Fichiers personnels",
+    "List of your files and folders that are not shared." : "Liste de vos fichiers et dossiers non partagés.",
+    "No personal files found" : "Aucun fichier personnel trouvé",
+    "Files that are not shared will show up here." : "Les fichiers qui ne sont pas partagés apparaîtront ici",
     "List of recently modified files and folders." : "Liste des fichiers et dossiers récemment modifiés.",
     "No recently modified files" : "Pas de fichiers récemment modifiés",
     "Files and folders you recently modified will show up here." : "Les fichiers et dossiers que vous avez récemment modifiés apparaîtront ici.",
     "No entries found in this folder" : "Aucune entrée trouvée dans ce dossier",
     "Select all" : "Tout sélectionner",
     "Upload too large" : "Données envoyées trop volumineuses",
-    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Les fichiers que vous essayez d'envoyer dépassent la taille maximale d'envoi permise par ce serveur.",
+    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Les fichiers que vous essayez d’envoyer dépassent la taille maximale d’envoi permise par ce serveur.",
     "Text file" : "Fichier texte",
     "New text file.txt" : "Nouveau fichier texte.txt",
+    "Direct link was copied (only works for users who have access to this file/folder)" : "Le lien direct a été copié (fonctionne uniquement pour les utilisateurs qui ont accès à ce fichier/dossier)",
+    "Copy direct link (only works for users who have access to this file/folder)" : "Copier le Lien direct (fonctionne uniquement pour les utilisateurs autorisés à accéder à ce fichier ou à ce dossier)",
     "You can only favorite a single file or folder at a time" : "Vous ne pouvez ajouter qu'un seul favori de dossier ou de fichier à la fois.",
-    "Search users" : "Rechercher des utilisateurs",
-    "You might not have have permissions to view it, ask the sender to share it" : "Vous n’avez peut-être pas les autorisations pour le voir, demandez à l’expéditeur de le partager",
-    "Cancel" : "Annuler",
-    "Set up templates folder" : "Configurer le dossier des modèles",
-    "Toggle %1$s sublist" : "Basculer %1$s sous-liste",
-    "Toggle grid view" : "Activer/Désactiver l'affichage mosaïque",
-    "Deleted files" : "Fichiers supprimés",
-    "Shares" : "Partages",
-    "Shared with others" : "Partagés avec d'autres",
-    "Shared with you" : "Partagés avec vous",
-    "Deleted shares" : "Partages supprimés",
-    "Pending shares" : "Partages en attente",
     "This file has the tag {tag}" : "Ce fichier a l'étiquette {tag}",
     "This file has the tags {firstTags} and {lastTag}" : "Ce fichier a les étiquettes {firstTags} et {lastTag}",
+    "\"remote user\"" : "\"utilisateur distant\"",
     "Select the row for {displayName}" : "Sélectionner la ligne pour {displayName}",
     "Open folder {name}" : "Ouvrir le dossier {name}",
     "Unselect all" : "Tout désélectionner",
@@ -327,6 +349,16 @@ OC.L10N.register(
     "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Cette liste n'est pas affichée en totalité pour des raisons de performances. Les fichiers seront affichés au fur et à mesure que vous parcourrez la liste.",
     "Search for an account" : "Chercher un compte",
     "Choose" : "Choisir",
-    "No files or folders have been deleted yet" : "Aucun fichier ou dossier n'a encore été supprimé"
+    "No files or folders have been deleted yet" : "Aucun fichier ou dossier n'a encore été supprimé",
+    "You might not have have permissions to view it, ask the sender to share it" : "Vous n’avez peut-être pas les autorisations pour le voir, demandez à l’expéditeur de le partager",
+    "Set up templates folder" : "Configurer le dossier des modèles",
+    "Toggle %1$s sublist" : "Basculer %1$s sous-liste",
+    "Toggle grid view" : "Activer/Désactiver l'affichage mosaïque",
+    "Shares" : "Partages",
+    "Shared with others" : "Partagés avec d'autres",
+    "Shared with you" : "Partagés avec vous",
+    "Deleted shares" : "Partages supprimés",
+    "Pending shares" : "Partages en attente",
+    "The files is locked" : "Le fichier est verrouillé"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
