@@ -3,7 +3,7 @@ OC.L10N.register(
     {
     "Please select a file." : "Seletziona un'archìviu.",
     "File is too big" : "S'archìviu est tropu mannu",
-    "The selected file is not an image." : "S'archìviu seletzionadu no est un'imàgine.",
+    "The selected file is not an image." : "S'archìviu seletzionadu no est un'immàgine.",
     "The selected file cannot be read." : "S'archìviu seletzionadu non si podet lèghere.",
     "The file was uploaded" : "S'archìviu est istadu carrigadu",
     "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "S'archìviu carrigadu superat sa diretiva upload_max_filesize in php.ini",
@@ -17,7 +17,7 @@ OC.L10N.register(
     "No image or file provided" : "Peruna immàgine o archìviu",
     "Unknown filetype" : "Genia de archìviu disconnota",
     "An error occurred. Please contact your admin." : "B'at àpidu un'errore. Cuntata s'amministratzione tua.",
-    "Invalid image" : "Imàgine non bàlida",
+    "Invalid image" : "Immàgine non bàlida",
     "No temporary profile picture available, try again" : "Peruna foto de profilu temporànea a disponimentu, torra a proare",
     "No crop data provided" : "Perunu datu frunidu",
     "No valid crop data provided" : "Perunu datu vàlidu frunidu",
@@ -36,15 +36,14 @@ OC.L10N.register(
     "Reset your password" : "Riprìstina sa crae",
     "Task not found" : "Faina no agatada!",
     "Internal error" : "Errore internu",
-    "No text to image provider is available" : "Nissunu servìtziu de cunversione de testu a imàgine a disponimentu",
-    "Image not found" : "Imàgine no agatada",
+    "No text to image provider is available" : "Nissunu servìtziu de cunversione de testu a immàgine a disponimentu",
+    "Image not found" : "Immàgine no agatada",
     "No translation provider available" : "Nissunu servìtziu de tradutzione a disponimentu",
     "Could not detect language" : "Impossìbile rilevare sa lìngua",
     "Unable to translate" : "Impossìbile tradùere",
     "Nextcloud Server" : "Serbidore de Nextcloud",
     "Some of your link shares have been removed" : "Carchi ligòngiu de cumpartzidura tuo nch'est istadu bogadu",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Pro un'errore de seguresa nch'amus dèpidu bogare carchi ligòngiu de cumpartzidura. Càstia su ligòngiu pro àteras informatziones.",
-    "The user limit of this instance is reached." : "S'est lòmpidu su lìmite de utèntzia pro custa istàntzia.",
     "Learn more ↗" : "Àteras informatziones ↗",
     "Preparing update" : "Aprontende s'agiornamentu",
     "[%d / %d]: %s" : "[%d / %d]: %s",
@@ -67,17 +66,8 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (non cumpatìbile)",
     "The following apps have been disabled: %s" : "Is aplicatziones in fatu sunt istadas disativadas: %s",
     "Already up to date" : "Giai agiornadu",
-    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Su serbidore tuo no est impostadu pro permìtere sa sincronizatzione de is archìvios, ca s'interfache WebDAV paret arrogada.",
-    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "Si serbidore tuo no est impostadu pro risòlvere \"{url}\". Podes agatare àteras informatziones in sa {linkstart} documentatzione ↗{linkend}..",
-    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Su serbidore internet tuo no est cunfiguradu comente si depet pro resòlvere \"{url}\". Est probàbile chi custu dipendat dae una cunfiguratzione de su serbidore no agiornada pro cunsignare deretu custa cartella. Cunfronta sa cunfiguratzione tua cun is règulas de re-iscritura imbiadas in \".htaccess\" pro Apache o cussa frunida in sa documentatzione pro Nginx in sa  {linkstart}pàgina de documentatzione ↗{linkend}. In Nginx giai semper sunt is lìneas chi incarrerant cun \"location ~\" chi tenent bisòngiu de un'agiornamentu.",
-    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "Su serbidore internet tuo no est cunfiguradu comente si depet pro produire archìvios .woff2. Custu est giai semper unu problema de sa cunfiguratzione Nginx. Pro Nextcloud 15 tocat de dd'adecuare pro produire puru archìvios .woff2. Cunfronta sa cunfiguratzione Nginx tua cun sa cunfiguratzione cussigiada in sa {linkstart}documentation ↗{linkend} nostra.",
-    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "Ses faghende s'atzessu a s'istàntzia dae una connessione segura, ma in cada manera s'istàntzia est generende URLs no seguros. Est meda probàbile chi siast a palas de unu serbidore intermèdiu e is variàbiles de sa cunfiguratzione de sa subra-iscritura no siant impostadas in sa manera curreta. Leghe {linkstart}sa pàgina de sa documentatzione subra de custu ↗{linkend}.",
     "Error occurred while checking server setup" : "Ddoe at àpidu un'errore in su controllu de sa cunfiguratzione de su serbidore",
     "For more details see the {linkstart}documentation ↗{linkend}." : "Pro àteros detàllios controlla sa {linkstart}documentatzione ↗{linkend}.",
-    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "S'intestatzione HTTP \"{header}\" no est impostada in \"{expected}\". Custu est un'arriscu possìbile de seguresa o privadesa, tando est cussigiadu a arrangiare cust'impostatzione de cunsighèntzia.",
-    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "S'intestatzione HTTP \"{header}\" no est impostada in \"{expected}\". Calicunu elementu diat pòdere no funtzionare in sa manera curreta, tando est cussigiadu a arrangiare cust'impostatzione de cunsighèntzia.",
-    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "S'intestatzione HTTP \"{header}\" no est impostada cun \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" o \"{val5}\". Custu podet fàghere essire informatziones de s'orìgine. Càstia sa {linkstart}W3C 1Racumandatzione ↗{linkend}.",
-    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "S'intestatzione HTTP \"Seguresa-Strinta-deTràmuda\" no est impostada pro a su mancu \"{segundos}\" segundos. Pro megiorare sa seguresa, est cussigiadu a ativare HSST comente descritu in is {linkstart}impòsitos de seguresa ↗{linkend}.",
     "unknown text" : "testu disconnotu",
     "Hello world!" : "Salude mundu!",
     "sunny" : "solianu",
@@ -98,6 +88,8 @@ OC.L10N.register(
     "More apps" : "Àteras aplicatziones",
     "Currently open" : "Abertos immoe",
     "_{count} notification_::_{count} notifications_" : ["{count} notìfica","{count} notìficas"],
+    "No" : "No",
+    "Yes" : "Eja",
     "Custom date range" : "Perìodu personalizadu",
     "Pick start date" : "Sèbera una data de cumintzu",
     "Pick end date" : "Sèbera una data de acabbu",
@@ -110,14 +102,10 @@ OC.L10N.register(
     "Please try again." : "Torra·nce a proare",
     "An internal error occurred." : "B'at àpidu un'errore internu.",
     "Please try again or contact your administrator." : "Torra a proare o cuntata s'amministratzione.",
-    "Account name or email" : "Nòmine de su contu o indiritzu de posta",
     "Password" : "Crae",
     "Log in to {productName}" : "Identìfica·ti in {productName}",
-    "Wrong username or password." : "Nùmene utente o crae isballiada.",
-    "User disabled" : "Utèntzia disativada",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Amus agatadu tentativos meda de atzessu dae s'IP tuo. Duncas s'atzessu tuo imbeniente dd'as a pòdere fàghere intre 30 segundos.",
     "Log in with a device" : "Autentica·ti cun unu dispositivu",
-    "Username or email" : "Nùmene utente o indiritzu de posta",
     "Your account is not setup for passwordless login." : "Su contu tuo no est fatu pro autenticatziones chene crae.",
     "Browser not supported" : "Navigadore non suportadu",
     "Passwordless authentication is not supported in your browser." : "S'autenticatzione chene crae no est suportada in su navigadore tuo.",
@@ -170,7 +158,6 @@ OC.L10N.register(
     "Unified search" : "Chirca unificada",
     "Search apps, files, tags, messages" : "Chirca in is aplicatziones, archìvios, etichetas e messàgios",
     "Search {types} …" : "Chirca {types} …",
-    "Apps and Settings" : "Aplicatziones e cunfiguratziones",
     "Date" : "Data",
     "Today" : "Oe ",
     "Last 7 days" : "Ùrtimas 7 dies",
@@ -189,9 +176,7 @@ OC.L10N.register(
     "Continue with this unsupported browser" : "Abarra in custu navigadore non cumpatìbile",
     "Supported versions" : "Versiones cumpatìbiles",
     "{name} version {version} and above" : "{name} versione {version} e superiores",
-    "Settings menu" : "Menu de is impostatziones",
-    "No" : "No",
-    "Yes" : "Eja",
+    "Settings menu" : "Menù de cunfiguratzione",
     "Choose {file}" : "Sèbera {file}",
     "Choose" : "Sèbera",
     "Copy to {target}" : "Còpia a {target}",
@@ -199,7 +184,6 @@ OC.L10N.register(
     "Move to {target}" : "Tràmuda a {target}",
     "Move" : "Tràmuda",
     "OK" : "AB",
-    "Error loading message template: {error}" : "Errore in su carrigamentu de su modellu de messàgiu: {error}",
     "read-only" : "letura sola",
     "_{count} file conflict_::_{count} file conflicts_" : ["{count} cunflitu de archìviu","{count} cunflitos de archìviu"],
     "One file conflict" : "Unu cunflitu de archìviu",
@@ -243,7 +227,6 @@ OC.L10N.register(
     "Collaborative tags" : "Etichetas collaborativas",
     "No tags found" : "Peruna eticheta agatada",
     "Personal" : "Personale",
-    "Users" : "Utentes",
     "Apps" : "Aplicatziones",
     "Admin" : "Amministratzione",
     "Help" : "Agiudu",
@@ -273,7 +256,6 @@ OC.L10N.register(
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Is cartellas de datos e is archìvios tuos fortzis sunt atzessìbiles dae s'internet ca s'archìviu .htaccess no est funtzionende.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Pro informatziones subra de comente cunfigurare su serbidore tuo, càstia in sa <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentatzione</a>.",
     "Create an <strong>admin account</strong>" : "Crea unu <strong>contu de amministratzione</strong>",
-    "Username" : "Nùmene utente",
     "Show password" : "Mustra crae",
     "Toggle password visibility" : "Càmbia sa visibilidade de sa crae",
     "Storage & database" : "Depòsitu e base de datos",
@@ -282,7 +264,6 @@ OC.L10N.register(
     "Only %s is available." : "%s isceti est a disponimentu.",
     "Install and activate additional PHP modules to choose other database types." : "Installa e ativa àteros mòdulos PHP pro seberare àteras genias de base de datos.",
     "For more details check out the documentation." : "Pro àteros detàllios controlla sa documentatzione.",
-    "Database user" : "Utente base de datos",
     "Database password" : "Crae base de datos",
     "Database name" : "Nùmene base de datos",
     "Database tablespace" : "Logu de sa tauledda de sa base de datos",
@@ -341,7 +322,6 @@ OC.L10N.register(
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Pro evitare pasadas cun installatziones mannas, podes dare su cumandu in fatu dae sa cartella de installatzione:",
     "Detailed logs" : "Registros detalliados",
     "Update needed" : "Tocat de agiornare",
-    "Please use the command line updater because you have a big instance with more than 50 users." : "Imprea s'atualizadore a lìnia de cummandu ca tenes un'istàntzia manna cun prus de 50 utentes.",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Pro agiudos, càstia sa  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentatzione</a>.",
     "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Giai dd'isco ca chi sigu cun s'agiornamentu via internet UI ddoe at s'arriscu chi sa rechesta arribet a una pasada e podet causare sa pèrdida de is datos, ma tèngio una còpia de seguresa e isco comente recuperare s'istàntzia in casu de errore.",
     "Upgrade via web on my own risk" : "Agiorna via web suta responsabilidade mia",
@@ -349,16 +329,20 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Immoe custa %s istàntzia est in modalidade de mantenidura, e podet trigare unu pagu.",
     "This page will refresh itself when the instance is available again." : "Custa pàgina s'at a atualizare cando s'istàntzia at a èssere torra a disponimentu.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Cuntata s'amministratzione de sistema si custu messàgiu abarrat o torrat a cumpàrrere",
-    "Please try again" : "Torra·nce a proare",
+    "The user limit of this instance is reached." : "S'est lòmpidu su lìmite de utèntzia pro custa istàntzia.",
+    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Su serbidore tuo no est impostadu pro permìtere sa sincronizatzione de is archìvios, ca s'interfache WebDAV paret arrogada.",
+    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "Si serbidore tuo no est impostadu pro risòlvere \"{url}\". Podes agatare àteras informatziones in sa {linkstart} documentatzione ↗{linkend}..",
+    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Su serbidore internet tuo no est cunfiguradu comente si depet pro resòlvere \"{url}\". Est probàbile chi custu dipendat dae una cunfiguratzione de su serbidore no agiornada pro cunsignare deretu custa cartella. Cunfronta sa cunfiguratzione tua cun is règulas de re-iscritura imbiadas in \".htaccess\" pro Apache o cussa frunida in sa documentatzione pro Nginx in sa  {linkstart}pàgina de documentatzione ↗{linkend}. In Nginx giai semper sunt is lìneas chi incarrerant cun \"location ~\" chi tenent bisòngiu de un'agiornamentu.",
+    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "Su serbidore internet tuo no est cunfiguradu comente si depet pro produire archìvios .woff2. Custu est giai semper unu problema de sa cunfiguratzione Nginx. Pro Nextcloud 15 tocat de dd'adecuare pro produire puru archìvios .woff2. Cunfronta sa cunfiguratzione Nginx tua cun sa cunfiguratzione cussigiada in sa {linkstart}documentation ↗{linkend} nostra.",
     "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "Paret chi PHP no est cunfigradu comente si depet pro rechèrrere variàbiles de ambiente de sistema. Sa proa cun getenv(\"PATH\") at torradu isceti una isceda bòida.",
     "Please check the {linkstart}installation documentation ↗{linkend} for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "Càstia sa {linkstart}documentatzione de installatzione ↗{linkend} pro is notas de cunfiguratzione de su PHP e sa cunfiguratzione de su serbidore tuo, prus che totu cando impreas php-fpm.",
     "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Sa cunfinguratzione de letura isceti est istètia ativada. Custu evitat de pònere cunfiguratziones cun sa interfache-web. In prus, s'archìviu depet èssere produidu pro èssere iscritu a manu a cada agiornamentu.",
     "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Sa base de datos tua non funtzionat cun su livellu de isulamentu de sa transatzione \"READ COMMITTED\". Custu podet causare problemas cando si faghent prus atziones in parallelu.",
     "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "Mancat su mòdulu PHP \"fileinfo\". Est cussigiadu meda de ativare custu mòdulu pro otènnere is mègius resurtados in sa chirca de sa genia MIME.",
     "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the {linkstart}documentation ↗{linkend} for more information." : "Su blocu de s'archìviu de transatzione est disativadu, e custu podet cumportare problemas cun is situatziones de carrera. Ativa \"filelocking.enabled\" in config.php pro evitare custos problemas. Càstia sa {linkstart}documentatzione ↗{linkend} pro àteras informatziones. ",
-    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "S'installatzione no tenet cunfigurada una regione pro su telèfonu predefinida. Custu serbit pro balidare is nùmeros de telèfonu in is impostatziones de profilu chene su còdighe de Istadu. Pro pòdere impreare nùmeros chene su còdighe de Istadu, agiunghe \"default_phone_region\" cun su relativu {linkstart}ISO 3166-1 code ↗{linkend} de sa regione pro cunfigurare s'archìviu tuo. ",
+    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "S'installatzione no tenet cunfigurada una regione pro su telèfonu predefinida. Custu serbit pro balidare is nùmeros de telèfonu in sa cunfiguratzione de profilu chene su còdighe de istadu. Pro pòdere impreare nùmeros chene su còdighe de istadu, agiunghe \"default_phone_region\" cun su relativu {linkstart}ISO 3166-1 code ↗{linkend} de sa regione pro cunfigurare s'archìviu tuo. ",
     "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Impossìbile a esecutare s'utilidade cron cun CLI. Sunt aparessidos is errores tècnicos in fatu:",
-    "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "S'urtima atividade de background est partida {relativeTime}. Calicuna cosa paret isballiada. {linkstart}Càstia is impostatziones de s'atividade de background ↗{linkend}.",
+    "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "Ùrtima atividade in segundu pranu: {relativeTime}. Calicuna cosa paret isballiada. {linkstart}Càstia sa cunfiguratzione de s'atividade in segundu pranu ↗{linkend}.",
     "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Peruna memòria de depòsitu cunfigurada. Pro megiorare s'esecutzione, cunfigura una memòria de depòsitu, si est disponìbile. Podes agatare àteras informatziones in sa {linkstart}documentatzione ↗{linkend}.",
     "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "PHP no at agatadu pro casualidade peruna orìgine adata e si cussìgiat de no ddu impreare pro resones de seguresa. Podes agatare àteras informatziones in sa {linkstart}documentatzione ↗{linkend}.",
     "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "Immoe ses impreende PHP {versione}. Agiorna sa versione tua de PHP pro isfrutare {linkstart}is novidades de esecutzione e seguresa frunidas dae su PHP Group ↗{linkend} cando sa distributzione tua ddas at a suportare.",
@@ -366,7 +350,7 @@ OC.L10N.register(
     "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the {linkstart}memcached wiki about both modules ↗{linkend}." : "Memcached est cunfiguradu comente su depòsitu distribuidu, ma est installadu su mòdulu PHP \"memcache\" isballiadu. \\OC\\Memcache\\Memcached suportat isceti \"memcached\" e no \"memcache\". Càstia sa {linkstart}memcached wiki subra de is duos mòdulos ↗{linkend}.",
     "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the {linkstart1}documentation ↗{linkend}. ({linkstart2}List of invalid files…{linkend} / {linkstart3}Rescan…{linkend})" : "Calicunu archìviu no at passadu su controllu de integridade. Podes agatare prus informatziones subra comente resòlvere custu problema in sa {linkstart1}documentatzione ↗{linkend}. ({linkstart2}Elencu de is archìvios non vàlidos…{linkend} / {linkstart3}Torra a analizare…{linkend})",
     "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "Sa funtzione PHP \"set_time_limit\" no est disponìbile. Custu podet essire in programmas firmados in cursu de esecutzione, trunchende s'installatzione. Est cussigiadu meda a ativare custa funtzione.",
-    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Su PHP tuo no tenet su suportu FreeType, e custu càusat dannos in is immàgines de profilu e in s'interfache de is impostatziones.",
+    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Su PHP tuo no tenet su suportu FreeType, e custu càusat dannos in is immàgines de profilu e in s'interfache de sa cunfiguratzione.",
     "Missing index \"{indexName}\" in table \"{tableName}\"." : "Mancat s'ìnditze \"{indexName}\" in sa tàula \"{tableName}\".",
     "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "In sa base de datos mancat calicunu ìnditze. Agiùnghere is ìnditzes a tàulas mannas podet pigare unu pagu de tempus, tando no s'agiunghent de manera automàtica. Impreende  \"occ db:add-missing-indices\" si podent agiùnghere a manu is ìnditzes chi mancant in s'interis chi s'istàntzia est in funtzione. Cando is ìnditzes sunt agiuntos is rechestas a custas tàulas andant giai semper prus a lestru meda.",
     "Missing primary key on table \"{tableName}\"." : "Mancat sa crae primària in sa tàula \"{tableName}\".",
@@ -381,10 +365,16 @@ OC.L10N.register(
     "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "Ddoe sunt cartella de aplicatzione de propiedade de utentes diversos dae su serbidore de internet. Podet èssere su casu de aplicatziones installadas a manu. Càstia is permissos relativos a is cartellas de aplicatziones in fatu:",
     "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read {linkstart}the documentation page about this ↗{linkend}." : "MySQL est impreadu comente base de datos ma no suportat is caràteres in 4-byte. Pro pòdere manigiare is caràteres in 4-byte (comente emojis) chena problemas pro esèmpiu in nùmenedearchìviu o in commentos, est cussugiadu ativare su suportu pro 4-byte in MySQL. Pro àteros detàllios leghe {linkstart}sa pàgina de sa documentatzione subre de custu ↗{linkend}.",
     "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "Custa istàntzia impreat un'ogetu de base S3 comente memòria primària. Is archìvios carrigados sunt allogados in manera temporale in su serbidore, tando est cussigiadu tènnere 50 GB de logu disponìbile in sa cartella temp de PHP. Càstia is registros pro totu is detàllios subra de su caminu e su logu disponìbile. Pro ddu megiorare càmbia sa cartella temporale in php.ini o faghe prus logu in custu caminu.",
-    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "Est istadu imbiadu unu messàgiu pro su risprìstinu de sa crae a s'indiritzu de posta eletrònica de custu contu. Si non ddu retzis, controlla in is cartellas de s'àliga o pide agiudu a s'amministratzione.",
-    "If it is not there ask your local administrator." : "Si no est in cue, dimanda a s'amministratzione locale tua.",
+    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "Ses faghende s'atzessu a s'istàntzia dae una connessione segura, ma in cada manera s'istàntzia est generende URLs no seguros. Est meda probàbile chi siast a palas de unu serbidore intermèdiu e is variàbiles de sa cunfiguratzione de sa subra-iscritura no siant impostadas in sa manera curreta. Leghe {linkstart}sa pàgina de sa documentatzione subra de custu ↗{linkend}.",
+    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "S'intestatzione HTTP \"{header}\" no est cunfigurada comente \"{expected}\". Custu est un'arriscu possìbile de seguresa o riservadesa, tando est cussigiadu a arrangiare custa cunfiguratzione.",
+    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "S'intestatzione HTTP \"{header}\" no est cunfigurada comente \"{expected}\". Calicunu elementu diat pòdere no funtzionare in sa manera curreta, tando est cussigiadu a arrangiare custa cunfiguratzione.",
+    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "S'intestatzione HTTP \"{header}\" no est impostada cun \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" o \"{val5}\". Custu podet fàghere essire informatziones de s'orìgine. Càstia sa {linkstart}W3C 1Racumandatzione ↗{linkend}.",
+    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "S'intestatzione HTTP \"Seguresa-Strinta-deTràmuda\" no est impostada pro a su mancu \"{segundos}\" segundos. Pro megiorare sa seguresa, est cussigiadu a ativare HSST comente descritu in is {linkstart}impòsitos de seguresa ↗{linkend}.",
+    "Account name or email" : "Nòmine de su contu o indiritzu de posta",
+    "Wrong username or password." : "Nùmene utente o crae isballiada.",
+    "User disabled" : "Utèntzia disativada",
+    "Username or email" : "Nùmene utente o indiritzu de posta",
     "Start search" : "Cumintza sa chirca",
-    "Press enter to start searching" : "Preme Enter pro cumintzare sa chirca",
     "Open settings menu" : "Aberi su menù de cunfiguratziones",
     "Settings" : "Cunfiguratziones",
     "Show all contacts …" : "Mustra totu is cuntatos ...",
@@ -400,6 +390,7 @@ OC.L10N.register(
     "\"{name}\" is not an allowed filetype" : "\"{name}\" no est una genia de archìviu permìtida",
     "{newName} already exists" : "{newName} esistit giai",
     "Error loading file picker template: {error}" : "Errore in su carrigamentu de su modellu de regorta de archìvios: {error}",
+    "Error loading message template: {error}" : "Errore in su carrigamentu de su modellu de messàgiu: {error}",
     "Show list view" : "Mustra sa visualizatzione de lista",
     "Show grid view" : "Mustra sa visualizatzione de mosàicu",
     "Pending" : "In suspesu",
@@ -410,9 +401,13 @@ OC.L10N.register(
     "This action requires you to confirm your password" : "Pro custa atzione ti tocat de cunfirmare sa crae",
     "Confirm" : "Cunfirma",
     "Failed to authenticate, try again" : "Impossìbile a s'autenticare, torra a proare",
-    "The page could not be found on the server." : "Impossìbile agatare custa pàgina in su serbidore.",
+    "Users" : "Utentes",
+    "Username" : "Nùmene utente",
+    "Database user" : "Utente base de datos",
     "Confirm your password" : "Cunfirma sa crae",
     "App token" : "Autenticadore de s'aplicatzione",
-    "Alternative log in using app token" : "Atzessu alternativu cun s'autenticadore de s'aplicatzione"
+    "Alternative log in using app token" : "Atzessu alternativu cun s'autenticadore de s'aplicatzione",
+    "Please use the command line updater because you have a big instance with more than 50 users." : "Imprea s'atualizadore a lìnia de cummandu ca tenes un'istàntzia manna cun prus de 50 utentes.",
+    "Apps and Settings" : "Aplicatziones e cunfiguratziones"
 },
 "nplurals=2; plural=(n != 1);");
