@@ -2,7 +2,6 @@ OC.L10N.register(
     "lib",
     {
     "Files" : "Ifuyla",
-    "Help" : "Tallalt",
     "Apps" : "Isnasen",
     "Settings" : "Iɣewwaṛen",
     "Log out" : "Senser",
@@ -13,6 +12,6 @@ OC.L10N.register(
     "Website" : "Asmel web",
     "Address" : "Adresse",
     "About" : "Γef",
-    "Full name" : "Isem inek ummid"
+    "Help" : "Tallalt"
 },
 "nplurals=2; plural=(n != 1);");
